.. stella documentation master file, created by
   sphinx-quickstart on Mon Sep 17 11:56:28 2018.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

stella
=====================================================
.. image:: ../figures/stella_logo.png
	:height: 300px
	:width: 600px
	:align: center

stella is an open-source python framework for identifying stellar flares using a neural network.

.. toctree::
   :maxdepth: 1
   :caption: Getting Started

   getting_started/about
   getting_started/installation
   getting_started/shortest_demo
   getting_started/tutorial
   getting_started/other_features

.. toctree::
   :maxdepth: 2
   :caption: Documentation

   api

Bug Reports, Questions, & Contributions
---------------------------------------

stella is an open source project under the MIT license. The source code is available on `GitHub`_. In case of any questions or problems, please contact us via the `Git Issues`_. Pull requests are also welcome through the GitHub page.


Index
-----
* :ref:`genindex`

.. _GitHub: http://github.com/afeinstein20/stella
.. _Git Issues: http://github.com/afeinstein20/stella/issues
